%% Info
%
%   Initialization file for the Guidance, Navigation and Control System
%   (GNC)
%
%
%   Aircraft used in simulation is the Cessna 172SP
%       Length:     27 ft  2 in    (8.28 m)
%       Height:      8 ft 11 in    (2.72 m)
%       Wingspan:   36 ft  1 in   (11.00 m)
%       Wing area:  174 sq ft     (16.20 m^2)
%       Weight:     1,717 lb      (779 kg)
%       
%       Max Takeoff Weight: 2,550 lb    (1 157 kg)
%       Max Payload Weight:   833 lb    (378 kg)
%
%
%   Author: Ingrid Hagen Johansen
%   Master Thesis Spring 2012
%   Date: 26.05.2012
%
%   Thanks to: Thor I. Fossen
%
%
%   
%
%
%


%%  Initialize simulation
%
%

% Initialize simulation variables

    sim_start = 0.0;
    sim_stop = 400;
 
% Real time setings
    realtime.scalingfactor = 0.05;

    
% Physics
    
    % Payload
    init_payload = [payload 0 0 0 0 0;
                    0 payload 0 0 0 0;
                    0 0 payload 0 0 0;
                    0 0 0 0 0 0;
                    0 0 0 0 0 0;
                    0 0 0 0 0 0];
                
    physics.g = 9.81;
    mass = [743.44 0 0 0 0 0;
            0 743.44 0 0 0 -996.21;
            0 0 743.44 0 996.21 0;
			0 0 0 2008.76 0 0;
			0 0 996.21 0 3827.04 0;					
			0 -996.21 0 0 0 5408.32]+ init_payload;
            


%% X-plane Interface

    x_plane_interface
                                        

                         
%% Reference Model

    % Commanded Speed
    reference.commandedSpeed.time = [0 150 150 sim_stop];
    reference.commandedSpeed.signals.values = [takeoff_speed takeoff_speed cruise_speed cruise_speed]';%Desired speed [kt]
    reference.commandedSpeed.signals.dimension = 1;
 
 
    % Commanded Altitude 
    reference.commandedHeight.time = [0 10 10 sim_stop];
    reference.commandedHeight.signals.values = [-Way_points(1,3) -Way_points(1,3) -Way_points(2,3) -Way_points(2,3)]';
    reference.commandedHeight.signals.dimension = 1;
    
    reference.lp.height.omega = 0.05;


%% Guidance 


    % Kp Kinematic Control Altitude  
    guidance.altitude.Kp = 1;

    % LOS Guidance
    % Calculate waypoint matrix for North-East

   for i = 1:length(Way_points)
       for j = 1:1
           guidance.waypoints(i,j) = Way_points(i,j);
           guidance.waypoints(i,j+1) = Way_points(i,j+1);
       end
   end

    % Kp = 1 / Lookahead Distance
    guidance.los.Kp = 1/600;
    
    % Natural Frequency Altitude LP
    guidance.alt.lp.omega = 0.05;
    
    % Natural Frequency Speed LP
    guidance.speed.lp.omega = 0.2;
    

%%  Control System


    % Speed controller
        % PID gains
        control.speed.kp = 0.01;
        control.speed.ki = 0.002;
        control.speed.kd = 0.01;
       
        % Saturation
        control.speed.uppersaturation = 1;
        control.speed.lowersaturation = 0.2;
      
        
    % Roll stabilizer controller
        % PID gains
        control.RollAngle.kp = 0.6;
        control.RollAngle.ki = 0.02;
        control.RollAngle.kd = 0; 
  
        
        % Saturation
        control.RollAngle.uppersaturation = 30*pi/180;
        control.RollAngle.lowersaturation = -30*pi/180;
        
        control.ailron.uppersaturation = 30*pi/180;
        control.ailron.lowersaturation = -30*pi/180;
        
        
    % Pitch angle controller
        % PID gains
        control.pitchAngle.kp = 0.5;
        control.pitchAngle.ki = 0.01;
        control.pitchAngle.kd = 0.01;
        
        % Saturation
        control.pitchAngle.uppersaturation = 20*pi/180;
        control.pitchAngle.lowersaturation = -20*pi/180;
        
        control.elevatorAngle.uppersaturation = 20*pi/180;
        control.elevatorAngle.lowersaturation = -20*pi/180;
        
        % Natural Frequency for Sliding Mode, Deflection Elevator LP        
        control.delta_e.lp.omega = 0.09;
        
    % Yaw angle controller
        % PID gains
        control.YawAngle.kp = 1; 
        control.YawAngle.ki = 0.1;
        control.YawAngle.kd = 0.01; 
       
        % Saturation
        control.YawAngle.uppersaturation = 15*pi/180;
        control.YawAngle.lowersaturation = -15*pi/180;



%%  Control Allocation

    allocation.B = [1 0 0 0;
                    0 1 0 1;
                    0 -1 0 -1;
                    0 0 -1 0;
                    0 0.02 0 0];


